==> vxl_1.13.0.orig.tar.gz: vxl-1.13.0/contrib/brl/bbas/bsta/tests/test_include.cxx <==
#include <bsta/bsta_histogram_sptr.h>
#include <bsta/bsta_joint_histogram_sptr.h>

#include <bsta/bsta_basic_functors.h>
#include <bsta/bsta_attributes.h>
#include <bsta/bsta_distribution.h>
#include <bsta/bsta_mixture.h>
#include <bsta/bsta_mixture_fixed.h>
#include <bsta/bsta_gaussian.h>
#include <bsta/bsta_gaussian_indep.h>
#include <bsta/bsta_gaussian_full.h>
#include <bsta/bsta_gaussian_sphere.h>
#include <bsta/bsta_gauss_fd3.h>
#include <bsta/bsta_gauss_ff3.h>
#include <bsta/bsta_gauss_id3.h>
#include <bsta/bsta_gauss_if3.h>
#include <bsta/bsta_gauss_sd3.h>
#include <bsta/bsta_gauss_sf3.h>

#include <bsta/bsta_detector_gaussian.h>
#include <bsta/bsta_detector_mixture.h>
#include <bsta/bsta_gauss.h>
#include <bsta/bsta_gauss_f1.h>
#include <bsta/bsta_gauss_f2.h>
#include <bsta/bsta_histogram.h>
#include <bsta/bsta_int_histogram_1d.h>
#include <bsta/bsta_int_histogram_2d.h>
#include <bsta/bsta_joint_histogram.h>
#include <bsta/bsta_histogram_base.h>
#include <bsta/bsta_joint_histogram_base.h>
#include <bsta/bsta_k_medoid.h>
#include <bsta/bsta_otsu_threshold.h>
#include <bsta/bsta_parzen.h>
#include <bsta/bsta_parzen_sf3.h>
#include <bsta/bsta_parzen_sf1.h>
#include <bsta/bsta_parzen_sphere.h>
#include <bsta/bsta_sampler.h>
#include <bsta/bsta_weibull.h>

#include <bsta/io/bsta_io_attributes.h>
#include <bsta/io/bsta_io_gaussian_full.h>
#include <bsta/io/bsta_io_gaussian_indep.h>
#include <bsta/io/bsta_io_gaussian_sphere.h>
#include <bsta/io/bsta_io_histogram.h>
#include <bsta/io/bsta_io_mixture.h>
#include <bsta/io/bsta_io_mixture_fixed.h>
#include <bsta/io/bsta_io_parzen_sphere.h>

int main() { return 0; }

==> vxl_1.14.0.orig.tar.gz: vxl-1.14.0/contrib/brl/bbas/bsta/tests/test_include.cxx <==
#include <bsta/bsta_histogram_sptr.h>
#include <bsta/bsta_joint_histogram_sptr.h>

#include <bsta/bsta_basic_functors.h>
#include <bsta/bsta_attributes.h>
#include <bsta/bsta_distribution.h>
#include <bsta/bsta_mixture.h>
#include <bsta/bsta_mixture_fixed.h>
#include <bsta/bsta_gaussian.h>
#include <bsta/bsta_gaussian_indep.h>
#include <bsta/bsta_gaussian_full.h>
#include <bsta/bsta_gaussian_sphere.h>
#include <bsta/bsta_gauss_fd3.h>
#include <bsta/bsta_gauss_ff3.h>
#include <bsta/bsta_gauss_id3.h>
#include <bsta/bsta_gauss_if3.h>
#include <bsta/bsta_gauss_sd3.h>
#include <bsta/bsta_gauss_sf2.h>
#include <bsta/bsta_gauss_sf3.h>
#include <bsta/bsta_beta.h>
#include <bsta/bsta_beta_f1.h>
#include <bsta/bsta_kent.h>

#include <bsta/bsta_detector_gaussian.h>
#include <bsta/bsta_detector_mixture.h>
#include <bsta/bsta_gauss.h>
#include <bsta/bsta_gauss_f1.h>
#include <bsta/bsta_gauss_f2.h>
#include <bsta/bsta_histogram.h>
#include <bsta/bsta_int_histogram_1d.h>
#include <bsta/bsta_int_histogram_2d.h>
#include <bsta/bsta_joint_histogram.h>
#include <bsta/bsta_histogram_base.h>
#include <bsta/bsta_joint_histogram_base.h>
#include <bsta/bsta_k_medoid.h>
#include <bsta/bsta_otsu_threshold.h>
#include <bsta/bsta_parzen.h>
#include <bsta/bsta_parzen_sf3.h>
#include <bsta/bsta_parzen_sf1.h>
#include <bsta/bsta_parzen_sphere.h>
#include <bsta/bsta_sampler.h>
#include <bsta/bsta_von_mises.h>
#include <bsta/bsta_weibull.h>

#include <bsta/io/bsta_io_attributes.h>
#include <bsta/io/bsta_io_beta.h>
#include <bsta/io/bsta_io_gaussian_full.h>
#include <bsta/io/bsta_io_gaussian_indep.h>
#include <bsta/io/bsta_io_gaussian_sphere.h>
#include <bsta/io/bsta_io_histogram.h>
#include <bsta/io/bsta_io_mixture.h>
#include <bsta/io/bsta_io_mixture_fixed.h>
#include <bsta/io/bsta_io_parzen_sphere.h>
#include <bsta/io/bsta_io_von_mises.h>

int main() { return 0; }
